@@ -81,10 +81,93 @@ int PyLong_AsInt(PyObject* obj, int* result) {
  *   is raised in this case.
  */
 int igraphmodule_PyObject_to_enum(PyObject *o,
+  igraphmodule_enum_translation_table_entry_t* table,
+  int *result) {
+
+  char *s, *s2;
+  int i, best, best_result, best_unique;
+
+  if (o == 0 || o == Py_None)
+    return 0;
+
+  if (PyLong_Check(o))
+    return PyLong_AsInt(o, result);
+
+  s = PyUnicode_CopyAsString(o);
+  if (s == 0) {
+    PyErr_SetString(PyExc_TypeError, "int, long or string expected");
+    return -1;
+  }
+
+  /* Convert string to lowercase */
+  for (s2 = s; *s2; s2++) {
+    *s2 = tolower(*s2);
+  }
+
+  /* Search for matches */
+  best = 0; best_unique = 0; best_result = -1;
+  while (table->name != 0) {
+    if (strcmp(s, table->name) == 0) {
+      /* Exact match found */
+      *result = table->value;
+      free(s);
+      return 0;
+    }
+
+    /* Find length of longest prefix that matches */
+    for (i = 0; s[i] == table->name[i]; i++);
+
+    if (i > best) {
+      /* Found a better match than before */
+      best = i; best_unique = 1; best_result = table->value;
+    } else if (i == best) {
+      /* Best match is not unique */
+      best_unique = 0;
+    }
+
+    table++;
+  }
+
+  free(s);
+
+  if (best_unique) {
+    PyErr_Warn(
+      PyExc_DeprecationWarning,
+      "Partial string matches of enum members are deprecated since igraph 0.9.3; "
+      "use strings that identify an enum member unambiguously."
+    );
+
+    *result = best_result;
+    return 0;
+  } else {
+    PyErr_SetObject(PyExc_ValueError, o);
+    return -1;
+  }
+}
+
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to a corresponding igraph enum, strictly.
+ *
+ * The numeric value is returned as an integer that must be converted
+ * explicitly to the corresponding igraph enum type. This is to allow one
+ * to use the same common conversion routine for multiple enum types.
+ *
+ * \param o a Python object to be converted
+ * \param translation the translation table between strings and the
+ *   enum values. Strings are treated as case-insensitive, but it is
+ *   assumed that the translation table keys are lowercase. The last
+ *   entry of the table must contain NULL values.
+ * \param result the result is returned here. The default value must be
+ *   passed in before calling this function, since this value is
+ *   returned untouched if the given Python object is Py_None.
+ * \return 0 if everything is OK, 1 otherwise. An appropriate exception
+ *   is raised in this case.
+ */
+int igraphmodule_PyObject_to_enum_strict(PyObject *o,
   igraphmodule_enum_translation_table_entry_t* table,
   int *result) {
     char *s, *s2;
-    int i, best, best_result, best_unique;
 
     if (o == 0 || o == Py_None)
       return 0;
@@ -98,26 +181,21 @@ int igraphmodule_PyObject_to_enum(PyObject *o,
     /* Convert string to lowercase */
     for (s2=s; *s2; s2++)
       *s2 = tolower(*s2);
-    best = 0; best_unique = 0; best_result = -1;
-    /* Search for matches */
+    /* Search for exact matches */
     while (table->name != 0) {
         if (strcmp(s, table->name) == 0) {
           *result = table->value;
           free(s);
           return 0;
         }
-        for (i=0; s[i] == table->name[i]; i++);
-        if (i > best) {
-            best = i; best_unique = 1; best_result = table->value;
-        } else if (i == best) best_unique = 0;
         table++;
     }
     free(s);
-    if (best_unique) { *result = best_result; return 0; }
     PyErr_SetObject(PyExc_ValueError, o);
     return -1;
 }
 
+
 /**
  * \ingroup python_interface_conversion
  * \brief Converts a Python object to an igraph \c igraph_neimode_t
@@ -176,6 +254,8 @@ int igraphmodule_PyObject_to_adjacency_t(PyObject *o,
         {"lower", IGRAPH_ADJ_LOWER},
         {"minimum", IGRAPH_ADJ_MIN},
         {"maximum", IGRAPH_ADJ_MAX},
+        {"min", IGRAPH_ADJ_MIN},
+        {"max", IGRAPH_ADJ_MAX},
         {"plus", IGRAPH_ADJ_PLUS},
         {0,0}
     };
@@ -188,6 +268,7 @@ int igraphmodule_PyObject_to_attribute_combination_type_t(PyObject* o,
   static igraphmodule_enum_translation_table_entry_t attribute_combination_type_tt[] = {
         {"ignore", IGRAPH_ATTRIBUTE_COMBINE_IGNORE},
         {"sum", IGRAPH_ATTRIBUTE_COMBINE_SUM},
+        {"prod", IGRAPH_ATTRIBUTE_COMBINE_PROD},
         {"product", IGRAPH_ATTRIBUTE_COMBINE_PROD},
         {"min", IGRAPH_ATTRIBUTE_COMBINE_MIN},
         {"max", IGRAPH_ATTRIBUTE_COMBINE_MAX},
@@ -196,6 +277,7 @@ int igraphmodule_PyObject_to_attribute_combination_type_t(PyObject* o,
         {"last", IGRAPH_ATTRIBUTE_COMBINE_LAST},
         {"mean", IGRAPH_ATTRIBUTE_COMBINE_MEAN},
         {"median", IGRAPH_ATTRIBUTE_COMBINE_MEDIAN},
+        {"concat", IGRAPH_ATTRIBUTE_COMBINE_CONCAT},
         {"concatenate", IGRAPH_ATTRIBUTE_COMBINE_CONCAT},
         {0, 0}
   };
@@ -405,6 +487,7 @@ int igraphmodule_PyObject_to_community_comparison_t(PyObject *o,
         {"nmi", IGRAPH_COMMCMP_NMI},
         {"danon", IGRAPH_COMMCMP_NMI},
         {"split-join", IGRAPH_COMMCMP_SPLIT_JOIN},
+        {"split_join", IGRAPH_COMMCMP_SPLIT_JOIN},
         {"rand", IGRAPH_COMMCMP_RAND},
         {"adjusted_rand", IGRAPH_COMMCMP_ADJUSTED_RAND},
         {0,0}
@@ -589,6 +672,31 @@ int igraphmodule_PyObject_to_subgraph_implementation_t(PyObject *o,
   return igraphmodule_PyObject_to_enum(o, subgraph_impl_tt, (int*)result);
 }
 
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to an igraph \c igraph_to_directed_t
+ */
+int igraphmodule_PyObject_to_to_directed_t(PyObject *o,
+  igraph_to_directed_t *result) {
+  static igraphmodule_enum_translation_table_entry_t to_directed_tt[] = {
+        {"acyclic",   IGRAPH_TO_DIRECTED_ACYCLIC},
+        {"arbitrary", IGRAPH_TO_DIRECTED_ARBITRARY},
+        {"mutual",    IGRAPH_TO_DIRECTED_MUTUAL},
+        {"random",    IGRAPH_TO_DIRECTED_RANDOM},
+        {0,0}
+  };
+
+  if (o == Py_True) {
+    *result = IGRAPH_TO_DIRECTED_MUTUAL;
+    return 0;
+  } else if (o == Py_False) {
+    *result = IGRAPH_TO_DIRECTED_ARBITRARY;
+    return 0;
+  }
+
+  return igraphmodule_PyObject_to_enum(o, to_directed_tt, (int*)result);
+}
+
 /**
  * \ingroup python_interface_conversion
  * \brief Converts a Python object to an igraph \c igraph_to_undirected_t
@@ -3025,3 +3133,49 @@ int igraphmodule_PyObject_to_pagerank_algo_t(PyObject *o, igraph_pagerank_algo_t
 
   return igraphmodule_PyObject_to_enum(o, pagerank_algo_tt, (int*)result);
 }
+
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to an igraph \c igraph_edge_type_sw_t
+ */
+int igraphmodule_PyObject_to_edge_type_sw_t(PyObject *o, igraph_edge_type_sw_t *result) {
+  static igraphmodule_enum_translation_table_entry_t edge_type_sw_tt[] = {
+        {"simple", IGRAPH_SIMPLE_SW},
+        {"loops", IGRAPH_LOOPS_SW},
+        {"multi", IGRAPH_MULTI_SW},
+        {"all", IGRAPH_LOOPS_SW | IGRAPH_MULTI_SW},
+        {0,0}
+    };
+
+  return igraphmodule_PyObject_to_enum_strict(o, edge_type_sw_tt, (int*)result);
+}
+
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to an igraph \c igraph_realize_degseq_t
+ */
+int igraphmodule_PyObject_to_realize_degseq_t(PyObject *o, igraph_realize_degseq_t *result) {
+  static igraphmodule_enum_translation_table_entry_t realize_degseq_tt[] = {
+        {"smallest", IGRAPH_REALIZE_DEGSEQ_SMALLEST},
+        {"largest", IGRAPH_REALIZE_DEGSEQ_LARGEST},
+        {"index", IGRAPH_REALIZE_DEGSEQ_INDEX},
+        {0,0}
+    };
+
+  return igraphmodule_PyObject_to_enum_strict(o, realize_degseq_tt, (int*)result);
+}
+
+/**
+ * \ingroup python_interface_conversion
+ * \brief Converts a Python object to an igraph \c igraph_random_tree_t
+ */
+int igraphmodule_PyObject_to_random_tree_t(PyObject *o, igraph_random_tree_t *result) {
+  static igraphmodule_enum_translation_table_entry_t random_tree_tt[] = {
+        {"prufer", IGRAPH_RANDOM_TREE_PRUFER},
+        {"lerw", IGRAPH_RANDOM_TREE_LERW},
+        {0,0}
+    };
+
+  return igraphmodule_PyObject_to_enum_strict(o, random_tree_tt, (int*)result);
+}
+
