@@ -23,15 +23,11 @@ Mac OS X users are likely to invoke igraph from the command line.
 import re
 import sys
 
-# pylint: disable-msg=W0401
-# W0401: wildcard import. That's exactly what we need for the shell.
-from igraph import __version__, set_progress_handler, set_status_handler
+from igraph import __version__
+from igraph._igraph import set_progress_handler, set_status_handler
 from igraph.configuration import Configuration
 
 
-# pylint: disable-msg=C0103,R0903
-# C0103: invalid name. Disabled because this is a third-party class.
-# R0903: too few public methods.
 class TerminalController:
     """
     A class that can be used to portably generate formatted output to
@@ -43,14 +39,14 @@ class TerminalController:
     output to the terminal:
 
         >>> term = TerminalController()
-        >>> print 'This is '+term.GREEN+'green'+term.NORMAL
+        >>> print('This is '+term.GREEN+'green'+term.NORMAL)
         This is green
 
     Alternatively, the `render()` method can used, which replaces
     '${action}' with the string required to perform 'action':
 
         >>> term = TerminalController()
-        >>> print term.render('This is ${GREEN}green${NORMAL}')
+        >>> print(term.render('This is ${GREEN}green${NORMAL}'))
         This is green
 
     If the terminal doesn't support a given action, then the value of
@@ -193,7 +189,7 @@ class TerminalController:
         the corresponding terminal control string (if it's defined) or
         '' (if it's not).
         """
-        return re.sub("r\$\$|\${\w+}", self._render_sub, template)
+        return re.sub("r\$\$|\${\w+}", self._render_sub, template)  # noqa: W605
 
     def _render_sub(self, match):
         """Helper function for L{render}"""
@@ -312,14 +308,12 @@ class Shell(object):
         called C{_status_handler}."""
         return hasattr(self, "_status_handler")
 
-    # pylint: disable-msg=E1101
     def get_progress_handler(self):
         """Returns the progress handler (if exists) or None (if not)."""
         if self.supports_progress_bar():
             return self._progress_handler
         return None
 
-    # pylint: disable-msg=E1101
     def get_status_handler(self):
         """Returns the status handler (if exists) or None (if not)."""
         if self.supports_status_messages():
@@ -511,11 +505,11 @@ def main():
             ]
         )
         for part in parts:
-            klass = available_classes.get(part, None)
-            if klass is None:
+            cls = available_classes.get(part, None)
+            if cls is None:
                 print("Warning: unknown shell class `%s'" % part, file=sys.stderr)
                 continue
-            shell_classes.append(klass)
+            shell_classes.append(cls)
     else:
         shell_classes = [IPythonShell, ClassicPythonShell]
         import platform
@@ -525,8 +519,6 @@ def main():
 
     shell = None
     for shell_class in shell_classes:
-        # pylint: disable-msg=W0703
-        # W0703: catch "Exception"
         try:
             shell = shell_class()
             break
