@@ -2,43 +2,13 @@
 # -*- coding: utf-8 -*-
 """Classes that help igraph communicate with Gephi (http://www.gephi.org)."""
 
-from igraph.compat import property
-import urllib.request, urllib.error, urllib.parse
-
-try:
-    # JSON is optional so we don't blow up with Python < 2.6
-    import json
-except ImportError:
-    try:
-        # Try with simplejson for Python < 2.6
-        import simplejson as json
-    except ImportError:
-        # No simplejson either
-        from igraph.drawing.utils import FakeModule
-
-        json = FakeModule()
+import json
+import urllib.error
+import urllib.parse
+import urllib.request
 
 __all__ = ("GephiConnection", "GephiGraphStreamer", "GephiGraphStreamingAPIFormat")
 __docformat__ = "restructuredtext en"
-__license__ = """\
-Copyright (C) 2006-2012  Tamás Nepusz <ntamas@gmail.com>
-Pázmány Péter sétány 1/a, 1117 Budapest, Hungary
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301 USA
-"""
 
 
 class GephiConnection(object):
@@ -202,7 +172,7 @@ class GephiGraphStreamer(object):
 
     The Gephi graph streaming format is a simple JSON-based format that can be used
     to post mutations to a graph (i.e. node and edge additions, removals and updates)
-    to a remote component. For instance, one can open up Gephi (http://www.gephi.org}),
+    to a remote component. For instance, one can open up Gephi (http://www.gephi.org),
     install the Gephi graph streaming plugin and then send a graph from igraph
     straight into the Gephi window by using `GephiGraphStreamer` with the
     appropriate URL where Gephi is listening.
@@ -215,7 +185,7 @@ class GephiGraphStreamer(object):
         >>> streamer = GephiGraphStreamer()
         >>> graph = Graph.Formula("A --> B, B --> C")
         >>> streamer.post(graph, buf)
-        >>> print buf.getvalue()         # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
+        >>> print(buf.getvalue())        # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
         {"an": {"igraph:...:v:0": {"name": "A"}}}
         {"an": {"igraph:...:v:1": {"name": "B"}}}
         {"an": {"igraph:...:v:2": {"name": "C"}}}
